@@ -6,7 +6,7 @@ use strict;
 
 use vars qw(@ISA $VERSION $CLASS *qv);
 
-$VERSION = 0.73;
+$VERSION = 0.76;
 
 $CLASS = 'version';
 
@@ -15,11 +15,23 @@ if ( $@ ) { # don't have the XS version installed
     eval "use version::vpp $VERSION"; # don't tempt fate
     die "$@" if ( $@ );
     push @ISA, "version::vpp";
+    local $^W;
     *version::qv = \&version::vpp::qv;
+    if ($] > 5.009001 && $] <= 5.010000) {
+	no strict 'refs';
+	*{'version::stringify'} = \*version::vpp::stringify;
+	*{'version::(""'} = \*version::vpp::stringify;
+    }
 }
 else { # use XS module
     push @ISA, "version::vxs";
+    local $^W;
     *version::qv = \&version::vxs::qv;
+    if ($] > 5.009001 && $] <= 5.010000) {
+	no strict 'refs';
+	*{'version::stringify'} = \*version::vxs::stringify;
+	*{'version::(""'} = \*version::vxs::stringify;
+    }
 }
 
 # Preloaded methods go here.
@@ -31,15 +43,6 @@ sub import {
     *{$callpkg."::qv"} = 
 	    sub {return bless version::qv(shift), $class }
 	unless defined(&{"$callpkg\::qv"});
-
-#    if (@_) { # must have initialization on the use line
-#	if ( defined $_[2] ) { # CVS style
-#	    $_[0] = version::qv($_[2]);
-#	}
-#	else {
-#	    $_[0] = version->new($_[1]);
-#	}
-#    }
 }
 
 1;
